@@ -12,7 +12,7 @@ from flit_core import common
 from .config import ConfigError
 from .log import enable_colourful_output
 
-__version__ = '3.5.0'
+__version__ = '3.6.0'
 
 log = logging.getLogger(__name__)
 
@@ -30,7 +30,7 @@ def find_python_executable(python: Optional[str] = None) -> str:
         return python
     # get absolute filepath of {python}
     # shutil.which may give a different result to the raw subprocess call
-    # see https://github.com/takluyver/flit/pull/300 and https://bugs.python.org/issue38905
+    # see https://github.com/pypa/flit/pull/300 and https://bugs.python.org/issue38905
     resolved_python = shutil.which(python)
     if resolved_python is None:
         raise PythonNotFoundError("Unable to resolve Python executable {!r}".format(python))
@@ -168,13 +168,6 @@ def main(argv=None):
 
     def gen_setup_py():
         if not (args.setup_py or args.no_setup_py):
-            log.info("Not generating setup.py in sdist (default changed)")
-            log.info(
-                "Recent versions of pip no longer need this generated file"
-            )
-            log.info(
-                "Use --[no-]setup-py to suppress this message or add setup.py"
-            )
             return False
         return args.setup_py
 
