@@ -205,7 +205,7 @@ class TerminalIniter(IniterBase):
         # than to do this through a TOML library.
         author_info = []
         if author:
-            author_info.append(f'name = {json.dumps(author)}')
+            author_info.append(f'name = {json.dumps(author, ensure_ascii=False)}')
         if author_email:
             author_info.append(f'email = {json.dumps(author_email)}')
         if author_info:
@@ -224,6 +224,8 @@ class TerminalIniter(IniterBase):
             ))
             if readme:
                 f.write(tomli_w.dumps({'readme': readme}))
+            if license != 'skip':
+                f.write('license = {file = "LICENSE"}\n')
             if classifiers:
                 f.write(f"classifiers = {json.dumps(classifiers)}\n")
             f.write('dynamic = ["version", "description"]\n')
