@@ -5,9 +5,9 @@ import logging
 import os
 import os.path as osp
 from pathlib import Path
-import tomli
 import re
 
+from .vendor import tomli
 from .versionno import normalise_version
 
 log = logging.getLogger(__name__)
@@ -287,7 +287,7 @@ def _prep_metadata(md_sect, path):
     res = LoadedConfig()
 
     res.module = md_sect.get('module')
-    if not str.isidentifier(res.module):
+    if not all([m.isidentifier() for m in res.module.split(".")]):
         raise ConfigError("Module name %r is not a valid identifier" % res.module)
 
     md_dict = res.metadata
