@@ -110,6 +110,7 @@ def test_init():
             data = tomli.load(f)
         assert data['project']['authors'][0]['email'] == "test@example.com"
         license = Path(td) / 'LICENSE'
+        assert data['project']['license']['file'] == 'LICENSE'
         assert_isfile(license)
         with license.open() as f:
             license_text = f.read()
@@ -222,3 +223,30 @@ def test_init_readme_found_yes_choosen():
         'readme': 'readme.md',
         'dynamic': ['version', 'description'],
     }
+
+
+def test_init_non_ascii_author_name():
+    responses = ['foo', # Module name
+                 'Test Authôr',      # Author
+                 '',  # Author email omitted
+                 '', # Home page omitted
+                 '1'    # License (1 -> MIT)
+                ]
+    with TemporaryDirectory() as td, \
+          patch_data_dir(), \
+          faking_input(responses):
+        ti = init.TerminalIniter(td)
+        ti.initialise()
+
+        generated = Path(td) / 'pyproject.toml'
+        assert_isfile(generated)
+        with generated.open('r', encoding='utf-8') as f:
+            raw_text = f.read()
+            print(raw_text)
+            assert "Test Authôr" in raw_text
+            assert "\\u00f4" not in raw_text
+        license = Path(td) / 'LICENSE'
+        assert_isfile(license)
+        with license.open(encoding='utf-8') as f:
+            license_text = f.read()
+        assert "Test Authôr" in license_text
